@@ -1,12 +1,12 @@
 from functools import partial
 
 import pytest
+
+from itsdangerous.url_safe import URLSafeSerializer
+from itsdangerous.url_safe import URLSafeTimedSerializer
 from test_itsdangerous.test_serializer import TestSerializer
 from test_itsdangerous.test_timed import TestTimedSerializer
 
-from itsdangerous import URLSafeSerializer
-from itsdangerous import URLSafeTimedSerializer
-
 
 class TestURLSafeSerializer(TestSerializer):
     @pytest.fixture()
